@@ -92,11 +92,10 @@ class Dungeon(Area):
                     elif room_number % self.rooms_per_level == 1:
                         my_room = MinionRoom(dun_level + self.cr)
                     elif room_number < self.total_rooms:
-                        my_room = Room(dun_level + self.cr,
-                                       make_traps=make_traps)
+                        my_room = Room(dun_level + self.cr, make_traps=make_traps)
                 else:
                     break
-                self.rooms.append(f'{self.name}\n{my_room}')
+                self.rooms.append(f'Room {room_number}, {my_room}')
                 self.threats.append(my_room)
                 self.total_xp += my_room.xp
         self.total_treasure = self.get_treasures()
@@ -108,7 +107,7 @@ class Dungeon(Area):
                 total += room.threat.treasure
         return total
 
-    def __repr__(self):
+    def __str__(self):
         output = (
             f"Dungeon: {self.name}\n",
             "\n".join(self.rooms),
@@ -116,6 +115,9 @@ class Dungeon(Area):
         )
         return "\n".join(output)
 
+    def print_room(self, room_number):
+        print(self.rooms[room_number-1])
+
 
 rand_color = TruffleShuffle((
     "Red",
@@ -450,7 +452,7 @@ class Settlement:
                 total += room.treasure
         return total
 
-    def __repr__(self):
+    def __str__(self):
         output = (
             f"Settlement: {self.name}\n",
             "\n".join(self.rooms),
@@ -467,12 +469,11 @@ class AdventureSet:
     def summary(self):
         return '\n'.join(f"{area.name}, CR {area.cr}" for area in self.areas)
 
-    def __repr__(self):
+    def __str__(self):
         return ''.join(str(area) for area in self.areas)
 
 
-if __name__ == "__main__":
-    print()
+def make_clichea():
     clichea = AdventureSet(
         Settlement(1, "Old Town"),
         Wilderness(1, "Gondar"),
@@ -515,4 +516,23 @@ if __name__ == "__main__":
         Dungeon(24, "Dark Tower"),
         CampaignBoss(25, "The Prince of Lies"),
     )
-    print(clichea)
+    return clichea
+
+
+if __name__ == "__main__":
+    print()
+    # adventure = AdventureSet(
+    #     Settlement(0, "Pissbottom Village"),
+    #     Wilderness(1, "Ever Wood Glade"),
+    #     Dungeon(2, "Obsidian Deep Mines"),
+    #     Settlement(2, "Moonville"),
+    #     Wilderness(3, "Gray Moore Swamp"),
+    #     Dungeon(4, "The Sunken Temple"),
+    #     Settlement(4, "Sunny Vale"),
+    #     Wilderness(5, "Mount Climax"),
+    #     Dungeon(6, "Halls of Mystery"),
+    #     CampaignBoss(7, "Damien"),
+    # )
+    # print(adventure)
+    d = Dungeon(3, dungeon_levels=10)
+    d.print_room(1)
